# Arad::Types::Int16 - a 16-bit SQL signed integer.
#
# Written by Shlomi Fish (shlomif@vipe.technion.ac.il), 1999
# This code is under the public domain. (It's uncopyrighted)


package Arad::Types::Int16;

use Arad::Types::Base;

@ISA = qw(Arad::Types::Base);

use strict;

my $min_value = -32768;
my $max_value = 32767;

sub initialize
{
    my $self = shift;

    $self->{'type'} = 'int16';
}

sub check_value
{
    my $self = shift;

    my $type_params = shift;
    my $value = shift;

    if (($value eq undef) || ($value eq ''))
    {
        return (0, "")
    }
    elsif ($value !~ /^[-+]?\d+$/)
    {
        return (1, "\$F must be an integer.");
    }
    elsif (($value > $max_value) || ($value < $min_value))
    {
        return (1, ("\$F must be in the range " . $min_value . " - " . $max_value . "."));
    }
    else
    {
        return (0, "");
    }
}

sub to_sql
{
    my $self = shift;

    my $type_params = shift;
    my $value = shift;

    if (($value eq undef) || ($value eq ''))
    {
        return (0, "null");
    }

    return (0, $value);
}

sub from_sql
{
    my $self = shift;

    my $type_params = shift;
    my $value = shift;

    if ($value eq undef)
    {
        return '';
    }

    return $value;
}

sub compare
{
    my $self = shift;

    my $type_params = shift;

    my $value1 = shift;
    my $value2 = shift;

    return ($value1 <=> $value2);
}
